==> haskell-aws-0.19-50-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.19
id: aws-0.19-DsAFdGFqHlRJOijka1KSO2
key: aws-0.19-DsAFdGFqHlRJOijka1KSO2
license: BSD3
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
author: Aristid Breitkreuz, contributors see README
exposed: True
indefinite: False
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutObject Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
abi: 6cbe1a0d26b32baa4834f558912ccc24
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aws-0.19
library-dirs: /usr/lib/ghc-8.2.2/site-local/aws-0.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/aws-0.19
hs-libraries: HSaws-0.19-DsAFdGFqHlRJOijka1KSO2
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15 base-4.10.1.0
    base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I
    conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg
    conduit-extra-1.2.3.2-GaOiiqhYFusHRrE0mLSTS0 containers-0.5.10.2
    cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    filepath-1.4.1.2 http-conduit-2.2.4-49vboQ3XHieEWbg3IvIExR
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz time-1.8.0.2
    transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    xml-conduit-1.7.1.2-DtRp2sBR6RSCNIRzDfaYkm
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8=37016c8c32a9f0915ad84c6171e7c01d
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I=6218d13b02d73798bf7f063f3f4fa054
             conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg=f28c447a2bec9bcfe4989e0ac67614c0
             conduit-extra-1.2.3.2-GaOiiqhYFusHRrE0mLSTS0=d137c1db69c44a9c422536419dd8db28
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I=96c7223eb24ebab9c9677bd383f9a0fa
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             http-conduit-2.2.4-49vboQ3XHieEWbg3IvIExR=8dd7a37d7aafccf796ac557f5f0099e0
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6=646a828923d0db6af349cf54aae99894
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=73bd87255495d2259f63e7f9009bea01
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=48449fd048b5d0ad9ccb1feb773de43b
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ=82fe21e10301e2e4d8701392ba21a740
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4=5d5f7a5bec88091b43d999202511397f
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI=a27ded325e5d5959c97ff2a5817450bc
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             xml-conduit-1.7.1.2-DtRp2sBR6RSCNIRzDfaYkm=f49c2709a718a78fa1915f96047323b2
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.19-65-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.19
id: aws-0.19-HZhFjBzulPWLHU6Y86YtiI
key: aws-0.19-HZhFjBzulPWLHU6Y86YtiI
license: BSD3
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
author: Aristid Breitkreuz, contributors see README
exposed: True
indefinite: False
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutObject Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
abi: 8ca61946e1059838927e1e906c14e45f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aws-0.19
library-dirs: /usr/lib/ghc-8.2.2/site-local/aws-0.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/aws-0.19
hs-libraries: HSaws-0.19-HZhFjBzulPWLHU6Y86YtiI
depends:
    aeson-1.2.4.0-Li9ssAeTb9P7oUJPRvxFf8
    attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv base-4.10.1.0
    base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I
    conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg
    conduit-extra-1.2.3.2-HZthckT96TfAIH6Yidaux4 containers-0.5.10.2
    cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    filepath-1.4.1.2 http-conduit-2.2.4-UrYYl0IFimCBAB62B0NDQ
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6
    memory-0.14.16-JXoliazMy4LBu5xxL66kmR
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    scientific-0.3.6.2-CyVAeaqQQPXHCT1PY3PkFn
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz time-1.8.0.2
    transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    xml-conduit-1.7.1.2-2RsWCdf7137EPB5YdK3vnm
abi-depends: aeson-1.2.4.0-Li9ssAeTb9P7oUJPRvxFf8=b6a260f9adf71cfb6ea790a11437cd4d
             attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base16-bytestring-0.1.1.6-Bd4rUARbKHBrsqzcqGjb8=37016c8c32a9f0915ad84c6171e7c01d
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I=6218d13b02d73798bf7f063f3f4fa054
             conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg=f28c447a2bec9bcfe4989e0ac67614c0
             conduit-extra-1.2.3.2-HZthckT96TfAIH6Yidaux4=251d7a2c728286b7a44ca0f856a6dc03
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-CpwkoOed0xp5yvbaGvna7I=96c7223eb24ebab9c9677bd383f9a0fa
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             http-conduit-2.2.4-UrYYl0IFimCBAB62B0NDQ=e36603df58ff456409864d484056d11d
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6=646a828923d0db6af349cf54aae99894
             memory-0.14.16-JXoliazMy4LBu5xxL66kmR=73bd87255495d2259f63e7f9009bea01
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=48449fd048b5d0ad9ccb1feb773de43b
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ=82fe21e10301e2e4d8701392ba21a740
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4=5d5f7a5bec88091b43d999202511397f
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             scientific-0.3.6.2-CyVAeaqQQPXHCT1PY3PkFn=b535f5c7ece7dcbe556eaf54ff052b22
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             xml-conduit-1.7.1.2-2RsWCdf7137EPB5YdK3vnm=a49dc5faef85b112ca9bf85751a3473f
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
